OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "En feil oppstod under generering av sikkerhetskopi-kodene",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Dette er sikkerhetskopi-kodene. Lagre og/eller skriv dem ut siden du ikke vil kunne se kodene her igjen senere.",
    "Save backup codes" : "Lagre sikkerhetskopi-kodene",
    "Print backup codes" : "Skriv ut sikkerhetskopi-koder",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Sikkerhetskoder er generert. {used} av {total} koder er brukt.",
    "Regenerate backup codes" : "Lag sikkerhetskopi-koder på nytt",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Hvis du regenererer nye sikkerhetskopi-koder, vil du automatisk gjøre de gamle kodene ugyldige.",
    "Generate backup codes" : "Generer sikkerhetskopi-koder",
    "You created two-factor backup codes for your account" : "Du opprettet to-trinns bekreftelse sikkerhetskopi-koder",
    "Second-factor backup codes" : "To-trinns bekreftelse sikkerhetskopi-koder",
    "Backup code" : "Sikkerhetskopi-kode",
    "Use backup code" : "Bruker sikkerhetskopi-kode",
    "Two factor backup codes" : "Sikkerhetskopikoder for tofaktor",
    "A two-factor auth backup codes provider" : "En leverandør av sikkerhetskopi av to-faktor koder",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Bruk en av backup kodene du lagret når du opprettet to-faktor autentisering.",
    "Submit" : "Send",
    "activated" : "aktivert",
    "updated" : "oppdatert",
    "mounted" : "tilkoblet",
    "deactivated" : "deaktivert",
    "beforeCreate" : "beforeCreate",
    "created" : "opprettet",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "ødelagt",
    "beforeMount" : "beforeMount",
    "Nextcloud backup codes" : "Nextcloud sikkerhetskopi-koder",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Du har aktivert to-faktor autentisering men har ikke generert backup koder. Vær sikker på å gjøre dette i tilfelle du mister tilgang til din andre faktor."
},
"nplurals=2; plural=(n != 1);");
